@@ -31,6 +31,48 @@ where
         Self { inner }
     }
 
+    /// Returns a reference to the underlying reader.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq as fastq;
+    /// let data = [];
+    /// let reader = fastq::Reader::new(&data[..]);
+    /// assert!(reader.get_ref().is_empty());
+    /// ```
+    pub fn get_ref(&self) -> &R {
+        &self.inner
+    }
+
+    /// Returns a mutable reference to the underlying reader.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq as fastq;
+    /// let data = [];
+    /// let mut reader = fastq::Reader::new(&data[..]);
+    /// assert!(reader.get_mut().is_empty());
+    /// ```
+    pub fn get_mut(&mut self) -> &mut R {
+        &mut self.inner
+    }
+
+    /// Unwraps and returns the underlying reader.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq as fastq;
+    /// let data = [];
+    /// let reader = fastq::Reader::new(&data[..]);
+    /// assert!(reader.into_inner().is_empty());
+    /// ```
+    pub fn into_inner(self) -> R {
+        self.inner
+    }
+
     /// Reads a FASTQ record.
     ///
     /// This reads from the underlying stream until four lines are read: the read name, the
@@ -103,42 +145,12 @@ where
     };
 
     len += read_line(reader, record.sequence_mut())?;
-    len += consume_line(reader)?;
+    len += read_description(reader, record.description_mut())?;
     len += read_line(reader, record.quality_scores_mut())?;
 
     Ok(len)
 }
 
-fn consume_line<R>(reader: &mut R) -> io::Result<usize>
-where
-    R: BufRead,
-{
-    let mut n = 0;
-    let mut is_eol = false;
-
-    while !is_eol {
-        let buf = reader.fill_buf()?;
-
-        if buf.is_empty() {
-            break;
-        }
-
-        let len = match buf.iter().position(|&b| b == LINE_FEED) {
-            Some(i) => {
-                is_eol = true;
-                i + 1
-            }
-            None => buf.len(),
-        };
-
-        reader.consume(len);
-
-        n += len;
-    }
-
-    Ok(n)
-}
-
 fn read_line<R>(reader: &mut R, buf: &mut Vec<u8>) -> io::Result<usize>
 where
     R: BufRead,
@@ -177,6 +189,21 @@ where
     }
 }
 
+fn read_description<R>(reader: &mut R, buf: &mut Vec<u8>) -> io::Result<usize>
+where
+    R: BufRead,
+{
+    const DESCRIPTION_PREFIX: u8 = b'+';
+
+    match read_u8(reader)? {
+        DESCRIPTION_PREFIX => read_line(reader, buf).map(|n| n + 1),
+        _ => Err(io::Error::new(
+            io::ErrorKind::InvalidData,
+            "invalid description prefix",
+        )),
+    }
+}
+
 fn read_u8<R>(reader: &mut R) -> io::Result<u8>
 where
     R: Read,
@@ -199,7 +226,7 @@ AGCT
 abcd
 @noodles:2/1
 TCGA
-+
++noodles:2/1
 dcba
 ";
 
@@ -207,10 +234,13 @@ dcba
         let mut record = Record::default();
 
         read_record(&mut reader, &mut record)?;
-        assert_eq!(record, Record::new("noodles:1/1", "AGCT", "abcd"));
+        let expected = Record::new("noodles:1/1", "AGCT", "abcd");
+        assert_eq!(record, expected);
 
         read_record(&mut reader, &mut record)?;
-        assert_eq!(record, Record::new("noodles:2/1", "TCGA", "dcba"));
+        let mut expected = Record::new("noodles:2/1", "TCGA", "dcba");
+        expected.description_mut().extend_from_slice(b"noodles:2/1");
+        assert_eq!(record, expected);
 
         let n = read_record(&mut reader, &mut record)?;
         assert_eq!(n, 0);
@@ -218,21 +248,6 @@ dcba
         Ok(())
     }
 
-    #[test]
-    fn test_consume_line() -> io::Result<()> {
-        fn t(mut data: &[u8], expected: &[u8]) -> io::Result<()> {
-            consume_line(&mut data)?;
-            assert_eq!(data, expected);
-            Ok(())
-        }
-
-        t(b"nd\nls\n", b"ls\n")?;
-        t(b"\nls\n", b"ls\n")?;
-        t(b"", b"")?;
-
-        Ok(())
-    }
-
     #[test]
     fn test_read_line() -> io::Result<()> {
         let mut buf = Vec::new();
@@ -278,4 +293,25 @@ dcba
 
         Ok(())
     }
+
+    #[test]
+    fn test_read_description() -> io::Result<()> {
+        let mut buf = Vec::new();
+
+        let data = b"+r0\n";
+        let mut reader = &data[..];
+        buf.clear();
+        read_description(&mut reader, &mut buf)?;
+        assert_eq!(buf, b"r0");
+
+        let data = b"r0\n";
+        let mut reader = &data[..];
+        buf.clear();
+        assert!(matches!(
+            read_description(&mut reader, &mut buf),
+            Err(ref e) if e.kind() == io::ErrorKind::InvalidData
+        ));
+
+        Ok(())
+    }
 }
