@@ -5,6 +5,7 @@ use std::fmt;
 pub struct Record {
     name: Vec<u8>,
     sequence: Vec<u8>,
+    description: Vec<u8>,
     quality_scores: Vec<u8>,
 }
 
@@ -26,6 +27,7 @@ impl Record {
         Self {
             name: name.into(),
             sequence: sequence.into(),
+            description: Vec::new(),
             quality_scores: quality_scores.into(),
         }
     }
@@ -57,7 +59,17 @@ impl Record {
         &self.name
     }
 
-    pub(crate) fn name_mut(&mut self) -> &mut Vec<u8> {
+    /// Returns a mutable reference to the name.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq::Record;
+    /// let mut record = Record::new("r0", "AGCT", "NDLS");
+    /// *record.name_mut() = b"r1".to_vec();
+    /// assert_eq!(record.name(), b"r1");
+    /// ```
+    pub fn name_mut(&mut self) -> &mut Vec<u8> {
         &mut self.name
     }
 
@@ -74,10 +86,47 @@ impl Record {
         &self.sequence
     }
 
-    pub(crate) fn sequence_mut(&mut self) -> &mut Vec<u8> {
+    /// Returns a mutable reference to the sequence.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq::Record;
+    /// let mut record = Record::new("r0", "AGCT", "NDLS");
+    /// record.sequence_mut()[0] = b'C';
+    /// assert_eq!(record.sequence(), b"CGCT");
+    /// ```
+    pub fn sequence_mut(&mut self) -> &mut Vec<u8> {
         &mut self.sequence
     }
 
+    /// Returns the description of the record.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq::Record;
+    /// let record = Record::new("r0", "AGCT", "NDLS");
+    /// assert!(record.description().is_empty());
+    /// ```
+    pub fn description(&self) -> &[u8] {
+        &self.description
+    }
+
+    /// Returns a mutable reference to the description.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq::Record;
+    /// let mut record = Record::new("r0", "AGCT", "NDLS");
+    /// *record.description_mut() = b"LN=4".to_vec();
+    /// assert_eq!(record.description(), b"LN=4");
+    /// ```
+    pub fn description_mut(&mut self) -> &mut Vec<u8> {
+        &mut self.description
+    }
+
     /// Returns the quality scores of the record.
     ///
     /// # Examples
@@ -91,7 +140,17 @@ impl Record {
         &self.quality_scores
     }
 
-    pub(crate) fn quality_scores_mut(&mut self) -> &mut Vec<u8> {
+    /// Returns a mutable reference to the quality scores.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_fastq::Record;
+    /// let mut record = Record::new("r0", "AGCT", "NDLS");
+    /// *record.quality_scores_mut() = b"!!!!".to_vec();
+    /// assert_eq!(record.quality_scores(), b"!!!!");
+    /// ```
+    pub fn quality_scores_mut(&mut self) -> &mut Vec<u8> {
         &mut self.quality_scores
     }
 
@@ -99,6 +158,7 @@ impl Record {
     pub(crate) fn clear(&mut self) {
         self.name.clear();
         self.sequence.clear();
+        self.description.clear();
         self.quality_scores.clear();
     }
 }
@@ -119,7 +179,13 @@ impl fmt::Display for Record {
 
         writeln!(f)?;
 
-        writeln!(f, "+")?;
+        f.write_str("+")?;
+
+        for &b in self.description() {
+            write!(f, "{}", b as char)?;
+        }
+
+        writeln!(f)?;
 
         for &b in self.quality_scores() {
             write!(f, "{}", b as char)?;
@@ -137,8 +203,11 @@ mod tests {
 
     #[test]
     fn test_fmt() {
-        let record = Record::new("r0", "ATCG", "NDLS");
+        let mut record = Record::new("r0", "ATCG", "NDLS");
         assert_eq!(record.to_string(), "@r0\nATCG\n+\nNDLS\n");
+
+        record.description_mut().extend_from_slice(b"r0");
+        assert_eq!(record.to_string(), "@r0\nATCG\n+r0\nNDLS\n");
     }
 
     #[test]
@@ -148,6 +217,7 @@ mod tests {
 
         assert!(record.name().is_empty());
         assert!(record.sequence().is_empty());
+        assert!(record.description().is_empty());
         assert!(record.quality_scores().is_empty());
     }
 }
